/* Generated by ./src/xlat/gen.sh from ./src/xlat/futexbitset.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(FUTEX_BITSET_MATCH_ANY) || (defined(HAVE_DECL_FUTEX_BITSET_MATCH_ANY) && HAVE_DECL_FUTEX_BITSET_MATCH_ANY)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((FUTEX_BITSET_MATCH_ANY) == (0xffffffff), "FUTEX_BITSET_MATCH_ANY != 0xffffffff");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define FUTEX_BITSET_MATCH_ANY 0xffffffff
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat futexbitset in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data futexbitset_xdata[] = {
 XLAT(FUTEX_BITSET_MATCH_ANY),
 #define XLAT_VAL_0 ((unsigned) (FUTEX_BITSET_MATCH_ANY))
 #define XLAT_STR_0 STRINGIFY(FUTEX_BITSET_MATCH_ANY)
};
static
const struct xlat futexbitset[1] = { {
 .data = futexbitset_xdata,
 .size = ARRAY_SIZE(futexbitset_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
