/* Generated by ./src/xlat/gen.sh from ./src/xlat/seccomp_ops.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat seccomp_ops in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data seccomp_ops_xdata[] = {
 [SECCOMP_SET_MODE_STRICT] = XLAT(SECCOMP_SET_MODE_STRICT),
 #define XLAT_VAL_0 ((unsigned) (SECCOMP_SET_MODE_STRICT))
 #define XLAT_STR_0 STRINGIFY(SECCOMP_SET_MODE_STRICT)
 [SECCOMP_SET_MODE_FILTER] = XLAT(SECCOMP_SET_MODE_FILTER),
 #define XLAT_VAL_1 ((unsigned) (SECCOMP_SET_MODE_FILTER))
 #define XLAT_STR_1 STRINGIFY(SECCOMP_SET_MODE_FILTER)
 [SECCOMP_GET_ACTION_AVAIL] = XLAT(SECCOMP_GET_ACTION_AVAIL),
 #define XLAT_VAL_2 ((unsigned) (SECCOMP_GET_ACTION_AVAIL))
 #define XLAT_STR_2 STRINGIFY(SECCOMP_GET_ACTION_AVAIL)
 [SECCOMP_GET_NOTIF_SIZES] = XLAT(SECCOMP_GET_NOTIF_SIZES),
 #define XLAT_VAL_3 ((unsigned) (SECCOMP_GET_NOTIF_SIZES))
 #define XLAT_STR_3 STRINGIFY(SECCOMP_GET_NOTIF_SIZES)
};
static
const struct xlat seccomp_ops[1] = { {
 .data = seccomp_ops_xdata,
 .size = ARRAY_SIZE(seccomp_ops_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
