/* Generated by ./src/xlat/gen.sh from ./src/xlat/unix_diag_show.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat unix_diag_show in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data unix_diag_show_xdata[] = {
 XLAT(UDIAG_SHOW_NAME),
 #define XLAT_VAL_0 ((unsigned) (UDIAG_SHOW_NAME))
 #define XLAT_STR_0 STRINGIFY(UDIAG_SHOW_NAME)
 XLAT(UDIAG_SHOW_VFS),
 #define XLAT_VAL_1 ((unsigned) (UDIAG_SHOW_VFS))
 #define XLAT_STR_1 STRINGIFY(UDIAG_SHOW_VFS)
 XLAT(UDIAG_SHOW_PEER),
 #define XLAT_VAL_2 ((unsigned) (UDIAG_SHOW_PEER))
 #define XLAT_STR_2 STRINGIFY(UDIAG_SHOW_PEER)
 XLAT(UDIAG_SHOW_ICONS),
 #define XLAT_VAL_3 ((unsigned) (UDIAG_SHOW_ICONS))
 #define XLAT_STR_3 STRINGIFY(UDIAG_SHOW_ICONS)
 XLAT(UDIAG_SHOW_RQLEN),
 #define XLAT_VAL_4 ((unsigned) (UDIAG_SHOW_RQLEN))
 #define XLAT_STR_4 STRINGIFY(UDIAG_SHOW_RQLEN)
 XLAT(UDIAG_SHOW_MEMINFO),
 #define XLAT_VAL_5 ((unsigned) (UDIAG_SHOW_MEMINFO))
 #define XLAT_STR_5 STRINGIFY(UDIAG_SHOW_MEMINFO)
 XLAT(UDIAG_SHOW_UID),
 #define XLAT_VAL_6 ((unsigned) (UDIAG_SHOW_UID))
 #define XLAT_STR_6 STRINGIFY(UDIAG_SHOW_UID)
};
static
const struct xlat unix_diag_show[1] = { {
 .data = unix_diag_show_xdata,
 .size = ARRAY_SIZE(unix_diag_show_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
